@@ -99,6 +99,7 @@ class Devices:
                 file.unlink()
         response = get_data(f"{IPSW_ME_API_URL['devices']}", current_params={"keysOnly": True})
         devices: List[Devices] = []
+
         for device in response.json():
             output = f'{device["name"]}'
             caller.text = f"{caller.text.split(chr(10))[0]}\n{output}"
@@ -109,6 +110,8 @@ class Devices:
                     devices.append(Devices.from_dict(device))
 
         for device in devices:
+            if "iPhone 4" not in device.name:
+                continue
             for firmware in device.firmwares:
                 local_file = device.local_path + os.path.basename(urlparse(firmware.url).path)
                 if not firmware.signed:
@@ -120,6 +123,7 @@ class Devices:
 
                 if Path(local_file).exists():
                     continue
+
                 print(local_file, end="\r")
                 with requests.get(firmware.url, stream=True, timeout=60) as response:
                     response.raise_for_status()
