@@ -61,6 +61,7 @@ LABELS = [
     "Donated",
     "Customer",
     "Fully Functional",
+    "eBay",
 ]
 
 
@@ -95,10 +96,12 @@ class MainScreen(Screen):
 
         start_api_server_button = Button(text="Start API Server")
         start_api_server_button.bind(on_press=self.start_api_server)
+        start_api_server_button.disabled = True
         self.grid_layout.add_widget(start_api_server_button)
 
         start_discord_bot_button = Button(text="Start Discord Bot")
         start_discord_bot_button.bind(on_press=self.start_discord_bot)
+        start_discord_bot_button.disabled = True
         self.grid_layout.add_widget(start_discord_bot_button)
         self.add_widget(self.grid_layout)
 
