@@ -5,19 +5,19 @@ import datetime
 from kivy.uix.button import Button
 from selenium import webdriver
 from shiny_api.classes import ls_item
+from shiny_api.modules import load_config as config
 
 print(f"Importing {os.path.basename(__file__)}...")
 
 
 def run_update_item_price(caller: Button):
     """ "//device key": ["current model?", "year", "basePrice", "cellPrice", "store URL"]"""
-    config_dir = os.path.dirname(os.path.abspath(__file__))
 
-    with open(f"{config_dir}/../config/devices.json", encoding="utf8") as file:
+    with open(f"{config.CONFIG_DIR}/../config/devices.json", encoding="utf8") as file:
         devices = json.load(file)
 
     # "//max age": "price multiplier"
-    with open(f"{config_dir}/../config/age.json", encoding="utf8") as file:
+    with open(f"{config.CONFIG_DIR}/config/age.json", encoding="utf8") as file:
         age_price = json.load(file)
 
     # Apple URL to load pricing from
